import setuptools
setuptools.setup(
    name= 'TANTEST',
    version= '0.1',
    author= 'TAN',
    description= 'MT FIRST LIB TEST IT ',
    packages=setuptools.find_packages(),
    classifiers=[
    "Programming Language :: Python :: 3",
    "Operating System :: OS Independent",
    "License :: OSI Approved :: MIT License"
    ]
)